Analytics class abstract

Base class for analytics services.

Implementers

Constructors

Analytics()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanUp() → void
Clean up resources.
flush() Future<void>
Flush pending analytics events.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEvent({required String event, Map<String, dynamic> properties = const {}}) Future<void>
Send an event to the analytics service.
toString() String
A string representation of this object.
inherited
track({required String event, Map<String, dynamic> properties = const {}}) → void
Track an event.

Operators

operator ==(Object other) bool
The equality operator.
inherited