BetterCommandRunnerFlags class abstract
Constants for the command runner flags.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- analytics → const String
- analyticsAbbr → const String
- analyticsOption → const FlagOption
- quiet → const String
- quietAbbr → const String
- quietOption → const FlagOption
- verbose → const String
- verboseAbbr → const String
- verboseOption → const FlagOption